@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 from lms.envs.production import *
+from openedx.core.djangoapps.plugins import constants as plugin_constants
 
 {% include "apps/openedx/settings/partials/common_lms.py" %}
 
@@ -21,3 +22,7 @@ LMS_CFG=/openedx/config/lms.yml
 {% endif %}
 
 {{ patch("openedx-lms-production-settings") }}
+
+# This is at the bottom because it is going to load more settings after base settings are loaded
+
+plugin_settings.add_plugins(__name__, plugin_constants.ProjectType.LMS, plugin_constants.SettingsType.PRODUCTION)
